from uuid import uuid4

from typing import Type, Any

from passlib.context import CryptContext
from tortoise import fields, models
from tortoise.models import MODEL


class User(models.Model):
    id = fields.UUIDField(pk=True, default=uuid4)
    username = fields.CharField(max_length=100, unique=True)
    name = fields.CharField(max_length=100)
    surname = fields.CharField(max_length=100)
    email = fields.CharField(max_length=100)
    created_at = fields.DatetimeField(auto_now_add=True)
    updated_at = fields.DatetimeField(auto_now=True)
    password = fields.CharField(max_length=255)

    def __str__(self):
        return self.name

    class Meta:
        table = 'users'

    @staticmethod
    def get_password_hash(password):
        pwd_context = CryptContext(schemes=["bcrypt"], deprecated="auto")
        return pwd_context.hash(password)

    @classmethod
    async def create(cls: Type[MODEL], **kwargs: Any) -> MODEL:
        kwargs['password'] = cls.get_password_hash(kwargs['password'])
        return await super().create(**kwargs)
