from uuid import UUID

import fastapi

from schemas import (
    UserAllOptionalSchema, CreateUserSchema, CreatedUserResponseSchema,
    UpdateUserSchema
)
from ctrl import UserController


router = fastapi.APIRouter(prefix='/users', tags=['AUTH'])
ctrl = UserController()


@router.get('')
async def get_users(query: UserAllOptionalSchema = fastapi.Depends()):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_users(id: UUID):
    return await ctrl.get(id)


@router.post('')
async def create_users(
        body: CreateUserSchema
) -> CreatedUserResponseSchema:
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_users(
    id: UUID, body: UpdateUserSchema,
) -> CreatedUserResponseSchema:
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_users(
    id: UUID,
):
    return await ctrl.delete(id)
